webuse nhanes2l
 
*Table 1
table (var) (highbp),  ///                         
       statistic(fvfrequency sex)   ///
       statistic(fvpercent   sex)   ///
       statistic(mean age)  ///
       statistic(sd age)  ///
       nototals ///
	   nformat(%9.0fc fvfrequency) ///
	   nformat(%6.2f mean sd) ///
	   sformat("%s%%" fvpercent) ///
	   sformat("(%s)" sd)
	   
*Table 1 (larger)
table (var) (highbp),  ///                           
       statistic(mean age bmi)   ///                  
       statistic(sd   age bmi)      ///               
       statistic(fvfrequency sex race hlthstat)   ///
       statistic(fvpercent   sex race hlthstat)   ///
       statistic(mean tcresult tgresult hdresult)  ///
       statistic(sd   tcresult tgresult hdresult)  ///
       nototal ///
	   nformat(%9.0fc fvfrequency) ///
	   nformat(%6.2f mean sd) ///
	   sformat("%s%%" fvpercent) ///
	   sformat("(%s)" sd)


*Single regression using the table command
table () (command result), /// no row dimensions, column dimensions are command and result
command(_r_b _r_ci _r_p: logistic highbp c.age##i.sex i.diabetes) /// pull the OR, CI and p-value
nformat(%5.2f  _r_b _r_ci ) /// formatting 2 digits to the right
nformat(%5.4f  _r_p) /// foratting 4 digits to the right
sformat("[%s]"  _r_ci ) cidelimiter(,) // "," between LCI and UCI
 
collect style cell cell_type[item column-header], halign(center)
collect label levels result _r_b "Odds Ratio", modify // changes label Coefficient to Odds Ratio
collect label levels command 1 "Logistic Regression Model for Hypertension", modify
collect style showbase off // hides base levels/reference groups of all factors 
collect style row stack, delimiter(" x ") nobinder // change interaction delimiter to x
collect style cell border_block, border(right, pattern(nil))
collect preview


*Single regression using the collect command
collect clear
collect _r_b _r_ci _r_p : logistic highbp c.age##i.sex i.diabetes
collect layout (colname)(result[_r_b _r_ci _r_p]) 	
collect style cell result[_r_b _r_ci], nformat(%5.2f)
collect style cell result[_r_p], nformat(%5.4f)
collect style cell result[_r_ci], sformat("[%s]") cidelimiter(,) 

collect style cell cell_type[item column-header], halign(center)
collect label levels result _r_b "Odds Ratio", modify // changes label Coefficient to Odds Ratio
collect style showbase off // hides base levels/reference groups of all factors 
collect style row stack, delimiter(" x ") nobinder // change interaction delimiter to x
collect style cell border_block, border(right, pattern(nil))
collect preview


*Multiple regressions side by side
collect clear
collect create MyModels
collect _r_b _r_se,                    ///
        name(MyModels)                 ///
        tag(model[(1)])                ///
        : logistic highbp c.age i.sex  
collect AIC=r(S)[1,"AIC"]    ///
        BIC=r(S)[1,"BIC"],   ///
        name(MyModels)       ///
        tag(model[(1)])      ///
        : estat ic
collect _r_b _r_se,                    ///
        name(MyModels)                 ///
        tag(model[(2)])                ///
        : logistic highbp c.age##i.sex	  
collect AIC=r(S)[1,"AIC"]    ///
        BIC=r(S)[1,"BIC"],   ///
        name(MyModels)       ///
        tag(model[(2)])      ///
        : estat ic
collect _r_b _r_se,                    ///
        name(MyModels)                 ///
        tag(model[(3)])                ///
        : logistic highbp c.age##i.sex	i.diabetes 
collect AIC=r(S)[1,"AIC"]    ///
        BIC=r(S)[1,"BIC"],   ///
        name(MyModels)       ///
        tag(model[(3)])      ///
        : estat ic
collect layout (colname#result result[AIC BIC]) (model), name(MyModels)
collect style cell cell_type[item column-header], halign(center) // CENTER ITEMS AND COLUMN HEADERS
collect style header result, level(hide) // HIDE LABELS FOR ROW DIMENSION RESULT
// TURN OFF BASE LEVELS FOR FACTOR VARIABLES
collect style showbase off
// CHANGE THE INTERACTION DELIMITER
collect style row stack, spacer delimiter(" x ")
// REMOVE THE VERTICAL LINE
collect style cell border_block, border(right, pattern(nil))
// FORMAT THE NUMBERS
collect style cell, nformat(%5.2f)
collect style cell result[AIC BIC], nformat(%8.0f)
// PUT PARENTHESES AROUND THE STANDARD ERRORS
collect style cell result[_r_se], sformat("(%s)")
// LABEL AIC AND BIC
collect style header result[AIC BIC], level(label)
collect preview

*PUTDOCX command for outputting tables to word
putdocx clear
putdocx begin
putdocx paragraph, style(Title)
putdocx text ("Hypertension in the United States")
putdocx paragraph, style(Heading1)
putdocx text ("The National Health and Nutrition Examination Survey (NHANES)")
putdocx paragraph
putdocx text ("Hypertension is a major cause of morbidity and mortality in ")
putdocx text ("the United States.  This report will explore the predictors ")
putdocx text ("of hypertension using the NHANES dataset.")
collect style putdocx, layout(autofitcontents)               ///
title("Table 4: Logistic Regression Model for Hypertension Status")
putdocx collect
putdocx save MyTable2.docx, replace

*Create and save user created style
collect style autolevels result N _r_b _r_ci , clear
collect layout (colname) (cmdset#result)
collect style column, dups(center)
collect style cell result, halign(center)
collect style save simple_regression, replace
